--
-- This script updates the schema of the Analytics database 7.0
--

BEGIN TRANSACTION;
GO

/****** Object:  View [dbo].[Source_TrafficByDay]    Script Date: 08/08/2013 11:01:03 ******/
IF  EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[Source_TrafficByDay]'))
DROP VIEW [dbo].[Source_TrafficByDay]
GO

/****** Object:  View [dbo].[Source_TrafficByDay]    Script Date: 08/08/2013 11:01:03 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE VIEW [dbo].[Source_TrafficByDay] AS
SELECT
  CAST( [Visits].[StartDateTime] AS DATE) AS [Date],
  [Visits].[TrafficType] AS [TrafficType],
  [Visits].[CampaignId] AS [CampaignId],
  [Pages].[ItemId] AS [ItemId],
  LOWER( SUBSTRING( CONVERT( VARCHAR(800), [ItemUrls].[Url] ), 1, CHARINDEX( '?', [ItemUrls].[Url] + '?' ) - 1 ) ) AS [Url],
  [Visits].[KeywordsId] AS [KeywordsId],
  LOWER( CONVERT( NVARCHAR(400), [Keywords].[Text] ) ) AS [Keywords],
  [Visits].[ReferringSiteId] AS [ReferringSiteId],
  LOWER( [ReferringSites].[Host] ) AS [ReferringSite],
  LOWER( [Visits].[Multisite] ) AS [Multisite],
  LOWER( [Visits].[DeviceName] ) AS [DeviceName],
  LOWER( [Visits].[Language] ) AS [Language],
  (CASE WHEN [Visits].[VisitorVisitIndex] = 1 THEN 1 ELSE 0 END) AS [FirstVisit],
  COUNT( 1 ) AS [Visits],
  SUM( [Visits].[Value] ) AS [Value]
FROM
  [dbo].[Visits] WITH (NOLOCK, FORCESEEK)
  INNER JOIN [dbo].[Pages] WITH (NOLOCK) ON ([Visits].[VisitId] = [Pages].[VisitId]) AND ([Visits].[VisitorId] = [Pages].[VisitorId]) AND ([Pages].[VisitPageIndex] = 1) AND ([Pages].[ItemId] <> '00000000-0000-0000-0000-000000000000')
  INNER JOIN [dbo].[Keywords] WITH (NOLOCK) ON ([Visits].[KeywordsId] = [Keywords].[KeywordsId])
  INNER JOIN [dbo].[ItemUrls] WITH (NOLOCK) ON ([Pages].[ItemId] = [ItemUrls].[ItemId])
  INNER JOIN [dbo].[ReferringSites] WITH (NOLOCK) ON ([Visits].[ReferringSiteId] = [ReferringSites].[ReferringSiteId])
  INNER JOIN [Visitors] WITH (NOLOCK) ON ([Visits].[VisitorId] = [Visitors].[VisitorId]) AND ([Visitors].[VisitorClassification] < 600)
GROUP BY
  CAST( [Visits].[StartDateTime] AS DATE),
  [Visits].[TrafficType],
  [Visits].[CampaignId],
  [Pages].[ItemId],
  LOWER( SUBSTRING( CONVERT( VARCHAR(800), [ItemUrls].[Url] ), 1, CHARINDEX( '?', [ItemUrls].[Url] + '?' ) - 1 ) ),
  [Visits].[KeywordsId],
  LOWER( CONVERT( NVARCHAR(400), [Keywords].[Text] ) ),
  [Visits].[ReferringSiteId],
  LOWER( [ReferringSites].[Host] ),
  LOWER( [Visits].[Multisite] ),
  LOWER( [Visits].[DeviceName] ),
  LOWER( [Visits].[Language] ),
  (CASE WHEN [Visits].[VisitorVisitIndex] = 1 THEN 1 ELSE 0 END)


GO

/****** Object:  View [dbo].[Source_ValueBySource]    Script Date: 08/08/2013 11:02:51 ******/
IF  EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[Source_ValueBySource]'))
DROP VIEW [dbo].[Source_ValueBySource]
GO

/****** Object:  View [dbo].[Source_ValueBySource]    Script Date: 08/08/2013 11:02:51 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE VIEW [dbo].[Source_ValueBySource] AS
SELECT
  CAST( [Visits].[StartDateTime] AS DATE) AS [Date],
  [Visits].[TrafficType] AS [TrafficType],
  LOWER( [Visits].[Multisite] ) AS [Multisite],
  LOWER( [Visits].[DeviceName] ) AS [DeviceName],
  LOWER([Visits].[Language]) [Language],
  SUM( [Visitors].[VisitCount] ) AS [Visits],
  SUM( [Visitors].[Value] ) AS [Value],
  SUM([Visits].[Value]) [FirstVisitValue],
  COUNT_BIG( 1 ) AS [Visitors]
FROM 
  [Visitors] WITH (NOLOCK)
  INNER JOIN [Visits] WITH (NOLOCK, FORCESEEK) ON ([Visits].[VisitorVisitIndex] = 1) AND ([Visits].[VisitorId] = [Visitors].[VisitorId])
  AND ([Visitors].VisitorClassification < 600)

GROUP BY 
  CAST( [Visits].[StartDateTime] AS DATE),
  [TrafficType],
  LOWER( [Visits].[Multisite] ),
  LOWER( [Visits].[DeviceName] ),
  LOWER( [Visits].[Language] )


GO

/****** Object:  View [dbo].[Source_VisitEvents]    Script Date: 08/08/2013 11:04:04 ******/
IF  EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[Source_VisitEvents]'))
DROP VIEW [dbo].[Source_VisitEvents]
GO

/****** Object:  View [dbo].[Source_VisitEvents]    Script Date: 08/08/2013 11:04:04 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE VIEW [dbo].[Source_VisitEvents] AS
SELECT
  CAST( [Visits].[StartDateTime] AS DATE ) AS [Date],
  [Visits].[VisitId] AS [VisitId],
  [Visits].[TrafficType] AS [TrafficType],
  [Visits].[CampaignId] AS [CampaignId],
  LOWER( [Visits].[Multisite] ) AS [Multisite],
  LOWER( [Visits].[DeviceName] ) AS [DeviceName],
  LOWER( [Visits].[Language] ) AS [Language],
  [Visits].[Value] AS [Value],
  [PageEvents].[PageEventDefinitionId] AS [PageEventDefinitionId],
  [PageEventDefinitions].[Name] AS [PageEventName],
  [PageEventDefinitions].[IsGoal] AS [IsGoal],
  [Pages].[ItemId] AS [ItemId],
  [PageEvents].[ItemId] AS [EventItemId],
  LOWER( [PageEvents].[DataKey] ) AS [DataKey],
  COUNT( 1 ) AS [NumberOfEvents]
FROM 
  [PageEvents] WITH (NOLOCK)
  INNER JOIN [Pages] WITH (NOLOCK) ON ([PageEvents].[PageId] = [Pages].[PageId]) AND ([PageEvents].[VisitId] = [Pages].[VisitId]) AND ([PageEvents].[VisitorId] = [Pages].[VisitorId])
  INNER JOIN [Visits] WITH (NOLOCK) ON ([Visits].[VisitId] = [PageEvents].[VisitId]) AND ([Visits].[VisitorId] = [PageEvents].[VisitorId])
  INNER JOIN [PageEventDefinitions] WITH (NOLOCK) ON ([PageEvents].[PageEventDefinitionId] = [PageEventDefinitions].[PageEventDefinitionId])
  INNER JOIN [Visitors] WITH (NOLOCK) ON ([Visitors].VisitorId = [Visits].[VisitorId]) AND ([Visitors].[VisitorClassification] < 600)
WHERE 
  ([PageEvents].[DataKey] > ' ') OR
  ([PageEventDefinitions].[IsGoal] = 1)
GROUP BY 
  CAST( [Visits].[StartDateTime] AS DATE ),
  [Visits].[VisitId],
  [Visits].[TrafficType],
  [Visits].[CampaignId],
  LOWER( [Visits].[Multisite] ),
  LOWER( [Visits].[DeviceName] ),
  LOWER( [Visits].[Language] ),
  [Visits].[Value], 
  [PageEvents].[PageEventDefinitionId],
  [PageEventDefinitions].[Name],
  [PageEventDefinitions].[IsGoal],
  LOWER( [PageEvents].[DataKey] ),
  [Pages].[ItemId],
  [PageEvents].[ItemId]


GO

/****** Object:  View [dbo].[Source_VisitorsByLocation]    Script Date: 08/08/2013 11:06:22 ******/
IF  EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[Source_VisitorsByLocation]'))
DROP VIEW [dbo].[Source_VisitorsByLocation]
GO

/****** Object:  View [dbo].[Source_VisitorsByLocation]    Script Date: 08/08/2013 11:06:22 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE VIEW [dbo].[Source_VisitorsByLocation] AS
SELECT
    CAST( [StartDateTime] AS DATE ) AS [Date],
    [Visitors].[VisitorClassification] AS [VisitorClassification],
    [LocationId] AS [LocationId],
    [Country] AS [Country],
	[BusinessName] AS [BusinessName],
    [Region] AS [Region],
    [Visits].[VisitorId] AS [VisitorId],
    COUNT_BIG( 1 ) AS [Visits],
    SUM( [Visits].[Value] ) AS [Value]
FROM
    [Visits] WITH (NOLOCK, FORCESEEK)
    INNER JOIN [Visitors] WITH (NOLOCK) ON ([Visits].[VisitorId] = [Visitors].[VisitorId]) AND ([Visitors].[VisitorClassification] < 600)
GROUP BY
    [Visits].[VisitorId],
    [LocationId],
    [Country],
    [BusinessName],
    [Region],
    [VisitorClassification],
    CAST( [StartDateTime] AS DATE )

GO

/****** Object:  View [dbo].[TrafficByCampaign]    Script Date: 08/08/2013 11:07:06 ******/
IF  EXISTS (SELECT * FROM sys.views WHERE object_id = OBJECT_ID(N'[dbo].[TrafficByCampaign]'))
DROP VIEW [dbo].[TrafficByCampaign]
GO

/****** Object:  View [dbo].[TrafficByCampaign]    Script Date: 08/08/2013 11:07:06 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE VIEW [dbo].[TrafficByCampaign] AS
WITH [Tbc] ( [CampaignId], [Visits], [Value] ) AS
(
  (
    SELECT
      [CampaignId] AS [CampaignId],
      SUM( [Visits] ) AS [Visits],
      SUM( [Value] ) AS [Value]
    FROM
      [dbo].[Cache_TrafficByDay]
    WHERE
      ([CampaignId] IS NOT NULL) AND
      ([CampaignId] <> '00000000-0000-0000-0000-000000000000') AND
      ([CampaignId] <> '00000001-0000-0000-0000-000000000000')
    GROUP BY
      [CampaignId]
  )
  UNION ALL
  (
    SELECT
      [Visits].[CampaignId] AS [CampaignId],
      COUNT( 1 ) AS [Visits],
      SUM( [Visits].[Value] ) AS [Value]
    FROM
      [dbo].[Visits] WITH (NOLOCK)
      INNER JOIN [Visitors] WITH (NOLOCK) ON ([Visitors].VisitorId = [Visits].[VisitorId]) AND ([Visitors].[VisitorClassification] < 600)
    WHERE
      ([Visits].[StartDateTime] > ISNULL( (SELECT MAX(cache.[Date]) FROM [Cache_TrafficByDay] cache), '0001-01-01' ) ) AND
      ([CampaignId] IS NOT NULL) AND
      ([CampaignId] <> '00000000-0000-0000-0000-000000000000') AND
      ([CampaignId] <> '00000001-0000-0000-0000-000000000000')
    GROUP BY
      [Visits].[CampaignId]
  )
)
SELECT
  [CampaignId] AS [CampaignId],
  SUM( [Visits] ) AS [Visits],
  SUM( [Value] ) AS [Value]
FROM
  [Tbc]
GROUP BY
  [CampaignId]


GO

COMMIT TRANSACTION;
GO
